@@ -6,6 +6,13 @@ from .config import set_backend
 
 
 # Dataloaders
-from .dataloaders.step import Step
+from .dataloaders.della_gatta_gene import DellaGattaGene
+from .dataloaders.mcycle import MotorcycleHelmet
+from .dataloaders.olympic import Olympic
+from .dataloaders.sinejump import SineJump1D
 from .dataloaders.smooth1d import Smooth1D
-from .dataloaders.olympic import Olympic
\ No newline at end of file
+from .dataloaders.step import Step
+
+
+
+
