@@ -2,8 +2,8 @@ import numpy as np
 from .base import Base
 
 class SineJump1D(Base):
-    def __init__(self, return_test=True, scale_X = True, scale_y = False, 
-                mean_normalize_y=True, test_train_ratio=2, 
+    def __init__(self, return_test=True, scale_X = True, scale_y = True, 
+                mean_normalize_y=False, test_train_ratio=2, 
                 s_to_n_ratio=10, noise_variance=None, scaler='std', 
                 min=-1, max=1, samples=101, random_state=0, backend=None):
         
